==> providence-reflect-0.3.16-sources.jar: net/morimekta/providence/reflect/parser/MessageProgramParser.java <==
/*
 * Copyright 2016 Providence Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package net.morimekta.providence.reflect.parser;

import net.morimekta.providence.model.ProgramType;
import net.morimekta.providence.serializer.Serializer;
import net.morimekta.providence.serializer.SerializerException;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.Collection;

/**
 * @author Stein Eldar Johnsen
 * @since 07.09.15
 */
public class MessageProgramParser implements ProgramParser {
    private final Serializer mSerializer;

    public MessageProgramParser(Serializer serializer) {
        mSerializer = serializer;
    }

    @Override
    public ProgramType parse(InputStream in, File file, Collection<File> includeDirs) throws IOException, ParseException {
        try {
            return mSerializer.deserialize(in, ProgramType.kDescriptor);
        } catch (SerializerException tse) {
            throw new ParseException("Failed to deserialize definition file.", tse);
        }
    }
}

==> providence-reflect-1.1.0-sources.jar: net/morimekta/providence/reflect/parser/MessageProgramParser.java <==
/*
 * Copyright 2016 Providence Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package net.morimekta.providence.reflect.parser;

import net.morimekta.providence.model.ProgramType;
import net.morimekta.providence.serializer.Serializer;
import net.morimekta.providence.serializer.SerializerException;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.Collection;

/**
 * @author Stein Eldar Johnsen
 * @since 07.09.15
 */
public class MessageProgramParser implements ProgramParser {
    private final Serializer mSerializer;

    public MessageProgramParser(Serializer serializer) {
        mSerializer = serializer;
    }

    @Override
    public ProgramType parse(InputStream in, File file, Collection<File> includeDirs) throws IOException, ParseException {
        try {
            return mSerializer.deserialize(in, ProgramType.kDescriptor);
        } catch (SerializerException tse) {
            throw new ParseException(tse, "Failed to deserialize definition file %s", file.getName())
                    .setFile(file.getName());
        }
    }
}
